pub enum ChronoTimerError<E>{
ChronoOutOfRange,
ImplementationSpecific {
source: E,
},
}Available on crate feature
chrono only.Expand description
Errors that can occur when scheduling with chrono::DateTime.
Variants
ChronoOutOfRange
The chrono time could not be converted into a SystemTime.
ImplementationSpecific
The underlying timer implementation returned an error.
Fields

source: ETrait Implementations
Sourceimpl<E> Debug for ChronoTimerError<E>
impl<E> Debug for ChronoTimerError<E>
Sourceimpl<E> Display for ChronoTimerError<E>
impl<E> Display for ChronoTimerError<E>
Sourceimpl<E> Error for ChronoTimerError<E>
impl<E> Error for ChronoTimerError<E>
Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourcefn cause(&self) -> Option<&dyn Error>
fn cause(&self) -> Option<&dyn Error>
👎Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
Sourceimpl<E> ErrorCompat for ChronoTimerError<E>
impl<E> ErrorCompat for ChronoTimerError<E>
Sourcefn iter_chain(&self) -> ChainCompat<'_, '_>where
Self: AsErrorSource,
fn iter_chain(&self) -> ChainCompat<'_, '_>where
Self: AsErrorSource,
Returns an iterator for traversing the chain of errors,
starting with the current error
and continuing with recursive calls to
Error::source. Read moreAuto Trait Implementations
impl<E> Freeze for ChronoTimerError<E>where
E: Freeze,
impl<E> RefUnwindSafe for ChronoTimerError<E>where
E: RefUnwindSafe,
impl<E> Send for ChronoTimerError<E>
impl<E> Sync for ChronoTimerError<E>
impl<E> Unpin for ChronoTimerError<E>where
E: Unpin,
impl<E> UnwindSafe for ChronoTimerError<E>where
E: UnwindSafe,