ClosureState

Struct ClosureState 

pub struct ClosureState<I> { /* private fields */ }
A timeout state for a timer using a closure as the triggering action.

Implementations

Source

impl<I> ClosureState<I>

pub fn new<F>(id: I, action: F) -> Self
where F: FnOnce(I) + Send + 'static,

Produces a new instance of this state type from a unique id and the action to be executed when it expires.