Module thread_timer

Module thread_timer 

Timer implementation that runs on its own thread and uses wall-clock deadlines.

This module emits errors via the log crate. Provide a logger implementation in your application to see these messages.

Structs

RealClock
System clock backed by SystemTime::now().
TimerRef
A reference to a thread timer.
TimerWithThread
A timer implementation that uses its own thread.

Enums

ThreadTimerError
Errors returned by the thread timer APIs.

Constants

DEFAULT_MAX_WAIT
Default value for [TimerWithThread::new] max_wait_time argument.

Traits

Clock
Abstraction over time for testing.

Type Aliases

ClosureTimerRef
A shorthand for a reference to a [TimerWithThread] with closure actions.
UuidClosureTimeruuid
A shorthand for a timer that uses UUID closure actions.
UuidClosureTimerRefuuid
A shorthand for a reference to a [TimerWithThread] with UUID closure actions.