State

Trait State 

pub trait State {
    type Id: Hash + Clone + Eq;

    // Required methods
    fn id(&self) -> &Self::Id;
    fn trigger(self);
}
A trait for state that can be triggered once.

Required Associated Types

type Id: Hash + Clone + Eq

The type of the unique id of the outstanding timeout.

Required Methods

fn id(&self) -> &Self::Id

A reference to the id associated with this state.

fn trigger(self)

Trigger is called by the timer implementation when the timeout has expired.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I> State for ClosureState<I>
where I: Hash + Clone + Eq,

Source

type Id = I