TimerWithThread

Struct TimerWithThread 

pub struct TimerWithThread<I, O>
where I: Hash + Clone + Eq + Ord, O: State<Id = I>,
{ /* private fields */ }
A timer implementation that uses its own thread.

This instance is essentially the owning handle. Non-owning references can be created with [TimerWithThread::timer_ref] and are always cloneable.

Implementations

Source

impl<I, O> TimerWithThread<I, O>
where I: Hash + Clone + Eq + Ord + Debug + Send + 'static, O: State<Id = I> + Debug + Send + 'static,

pub fn new( max_wait_time: Duration, ) -> Result<TimerWithThread<I, O>, ThreadTimerError>

Create a new timer with its own thread.

max_wait_time is the maximum time we wait until we check the clock again, in case it jumped (e.g. after sleep or due to a timezone change).

pub fn new_with_clock<C>( clock: C, max_wait_time: Duration, ) -> Result<TimerWithThread<I, O>, ThreadTimerError>
where C: Clock,

Create a new timer with its own thread using a custom clock.

This is mostly meant for testing, but can also be used to supply other clock sources than [SystemTime].

max_wait_time is the maximum time we wait until we check the clock again, in case it jumped (e.g. after sleep or due to a timezone change).

pub fn timer_ref(&self) -> TimerRef<I, O>

Returns a shareable reference to this timer.

pub fn shutdown(self) -> Result<(), ThreadTimerError>

Shut this timer down and wait for the thread to join.

pub fn shutdown_async(&self) -> Result<(), ThreadTimerError>

Same as shutdown, but doesn’t wait for the thread to join.

Source

impl TimerWithThread<Uuid, ClosureState<Uuid>>

pub fn for_uuid_closures( max_wait_time: Duration, ) -> Result<Self, ThreadTimerError>

Available on crate feature uuid only.

Create a UUID-based timer using closure states.